import { getLeafDeserializer, useRenderLeaf, useOnKeyDownMark } from '@udecode/slate-plugins-common';
import { getSlatePluginOptions } from '@udecode/slate-plugins-core';

const MARK_HIGHLIGHT = 'highlight';
const DEFAULTS_HIGHLIGHT = {
  hotkey: 'mod+shift+h'
};

const useDeserializeHighlight = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_HIGHLIGHT);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['MARK']
      }]
    }, options.deserialize))
  };
};

/**
 * Enables support for highlights, useful when reviewing
 * content or highlighting it for future reference.
 */

const useHighlightPlugin = () => ({
  pluginKeys: MARK_HIGHLIGHT,
  renderLeaf: useRenderLeaf(MARK_HIGHLIGHT),
  deserialize: useDeserializeHighlight(),
  onKeyDown: useOnKeyDownMark(MARK_HIGHLIGHT)
});

export { DEFAULTS_HIGHLIGHT, MARK_HIGHLIGHT, useDeserializeHighlight, useHighlightPlugin };
//# sourceMappingURL=index.es.js.map
